import React, { Fragment } from 'react'
import { H3 } from '@pubsweet/ui'
import { get, has } from 'lodash'
import { withRouter } from 'react-router-dom'
import { ManuscriptCard, Row } from 'pubsweet-component-faraday-ui'
import { compose, setDisplayName, withHandlers, withProps } from 'recompose'

import withVersion from './withVersion'

const DashboardItem = withVersion(ManuscriptCard)

const DashboardItems = ({ onClick, list, deleteProject, listView = true }) => (
  <Fragment>
    {!list.length ? (
      <Row justify="center" mt={4}>
        <H3>Nothing to do at the moment. Please upload a manuscript.</H3>
      </Row>
    ) : (
      list.map(collection => (
        <DashboardItem
          collection={collection}
          key={collection.id}
          onClick={onClick}
        />
      ))
    )}
  </Fragment>
)

export default compose(
  withRouter,
  withProps(({ collection = {}, fragment = {} }) => ({
    hasDetails: get(collection, 'status', 'draft') !== 'draft',
    isNotSubmitted:
      get(collection, 'status', 'draft') === 'draft' ||
      !has(fragment, 'submitted'),
  })),
  withHandlers({
    onClick: ({ history, hasDetails, isNotSubmitted }) => (
      collection,
      fragment,
    ) => {
      if (isNotSubmitted) {
        history.push(
          `/projects/${collection.id}/versions/${fragment.id}/submit`,
        )
      } else if (hasDetails) {
        history.push(
          `/projects/${collection.id}/versions/${fragment.id}/details`,
        )
      }
    },
  }),
  setDisplayName('DashboardItems'),
)(DashboardItems)
